# History

## 0.1.0 (2025)

- Initial release
- Forked from Cookiecutter v2.6.0
- Full rebrand to aiclimate
- Built-in ML/climate template with uv support
- Dual-format support (aiclimate.json + cookiecutter.json)
